==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PriorityClassFluent.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V1alpha1PriorityClassFluent<A extends V1alpha1PriorityClassFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public Boolean isGlobalDefault();
    public A withGlobalDefault(Boolean globalDefault);
    public Boolean hasGlobalDefault();
    public A withNewGlobalDefault(boolean arg1);
    public A withNewGlobalDefault(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1PriorityClassFluent.MetadataNested<A> editMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public Integer getValue();
    public A withValue(Integer value);
    public Boolean hasValue();
    public A withNewValue(int arg1);
    public A withNewValue(String arg1);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1PriorityClassFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PriorityClassFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V1alpha1PriorityClassFluent<A extends V1alpha1PriorityClassFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(String arg1);
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(StringBuffer arg1);
    public Boolean isGlobalDefault();
    public A withGlobalDefault(Boolean globalDefault);
    public Boolean hasGlobalDefault();
    public A withNewGlobalDefault(String arg1);
    public A withNewGlobalDefault(boolean arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public V1alpha1PriorityClassFluent.MetadataNested<A> editMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PriorityClassFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    public Integer getValue();
    public A withValue(Integer value);
    public Boolean hasValue();

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<V1alpha1PriorityClassFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
